@@ -1,7 +1,7 @@
 `w_mode` <- function(x, wt = NULL) {
 
     if (inherits(x, "haven_labelled")) {
-        x <- as_declared(x)
+        x <- as.declared(x)
     }
 
     if (!(is.atomic(x) && (is.numeric(x) || is.complex(x) || is.logical(x)))) {
@@ -19,15 +19,15 @@
     }
 
     if (!(is.atomic(wt) && all(is.finite(na.omit(wt))))) {
-        admisc::stopError("'wt' should be an atomic vector with finite values.")
+        stopError_("'wt' should be an atomic vector with finite values.")
     }
 
     tbl <- w_table(x, wt = wt)
     wm <- which.max(tbl)
     
     fmode <- names(tbl[wm])
-    if (admisc::possibleNumeric(fmode)) {
-        fmode <- admisc::asNumeric(fmode)
+    if (possibleNumeric_(fmode)) {
+        fmode <- asNumeric_(fmode)
     }
 
     if (length(tbl[tbl == max(tbl)]) > 1) {
