@@ -7,7 +7,7 @@
     wsum <- c(wsum[1:3], wmean, wsum[4:5])
 
     if (inherits(x, "haven_labelled")) {
-        x <- as_declared(x)
+        x <- as.declared(x)
     }
 
     nas <- w_table(is.na(undeclare(x)), wt = wt)
@@ -19,6 +19,6 @@
         wsum <- c(wsum, "NA's" = nas$fre[2])
     }
 
-    class(wsum) <- c("admisc_fobject", class(wsum))
+    class(wsum) <- c("fobject", class(wsum))
     return(wsum)
 }
